import OCP.Units
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import OCP.TColStd
import OCP.NCollection
import OCP.Standard
__all__  = [
"Units",
"Units_Dimensions",
"Units_Explorer",
"Units_Lexicon",
"Units_Sentence",
"Units_Measurement",
"Units_NoSuchType",
"Units_NoSuchUnit",
"Units_QtsSequence",
"Units_QuantitiesSequence",
"Units_Quantity",
"Units_MathSentence",
"Units_Token",
"Units_Unit",
"Units_TksSequence",
"Units_ShiftedToken",
"Units_TokensSequence",
"Units_ShiftedUnit",
"Units_UnitSentence",
"Units_UnitsDictionary",
"Units_UnitsLexicon",
"Units_UtsSequence",
"Units_UnitsSystem",
"Units_UnitsSequence",
"__add__",
"__mul__",
"__rmul__",
"__sub__",
"__truediv__",
"pow"
]
class Units():
    """
    This package provides all the facilities to create and question a dictionary of units, and also to manipulate measurements which are real values with units.
    """
    @staticmethod
    def Convert_s(avalue : float,afirstunit : str,asecondunit : str) -> float: 
        """
        Converts <avalue> expressed in <afirstunit> into the <asecondunit>.
        """
    @staticmethod
    def DictionaryOfUnits_s(amode : bool=False) -> Units_UnitsDictionary: 
        """
        Returns a unique instance of the dictionary of units. If <amode> is True, then it forces the recomputation of the dictionary of units.
        """
    @staticmethod
    def Dimensions_s(aType : str) -> Units_Dimensions: 
        """
        return the dimension associated to the Type
        """
    @staticmethod
    def FirstQuantity_s(aunit : str) -> str: 
        """
        Returns the first quantity string founded from the unit <aUnit>.
        """
    @staticmethod
    @overload
    def FromSI_s(aData : float,aUnit : str) -> float: ...
    @staticmethod
    @overload
    def FromSI_s(aData : float,aUnit : str,aDim : Units_Dimensions) -> float: ...
    @staticmethod
    def LexiconFile_s(afile : str) -> None: 
        """
        Defines the location of the file containing the lexicon useful in manipulating composite units.
        """
    @staticmethod
    def LexiconFormula_s() -> Units_Lexicon: 
        """
        Return a unique instance of LexiconFormula.
        """
    @staticmethod
    def LexiconUnits_s(amode : bool=True) -> Units_Lexicon: 
        """
        Returns a unique instance of the Units_Lexicon. If <amode> is True, it forces the recomputation of the dictionary of units, and by consequence the completion of the Units_Lexicon.
        """
    @staticmethod
    def NullDimensions_s() -> Units_Dimensions: 
        """
        Returns always the same instance of Dimensions.
        """
    @staticmethod
    def Quantity_s(aquantity : str) -> Units_Quantity: 
        """
        Returns a unique quantity instance corresponding to <aquantity>.
        """
    @staticmethod
    @overload
    def ToSI_s(aData : float,aUnit : str) -> float: ...
    @staticmethod
    @overload
    def ToSI_s(aData : float,aUnit : str,aDim : Units_Dimensions) -> float: ...
    @staticmethod
    def UnitsFile_s(afile : str) -> None: 
        """
        Defines the location of the file containing all the information useful in creating the dictionary of all the units known to the system.
        """
    def __init__(self) -> None: ...
    pass
class Units_Dimensions(OCP.Standard.Standard_Transient):
    """
    This class includes all the methods to create and manipulate the dimensions of the physical quantities.This class includes all the methods to create and manipulate the dimensions of the physical quantities.This class includes all the methods to create and manipulate the dimensions of the physical quantities.
    """
    @staticmethod
    def AAmountOfSubstance_s() -> Units_Dimensions: ...
    @staticmethod
    def AElectricCurrent_s() -> Units_Dimensions: ...
    @staticmethod
    def ALength_s() -> Units_Dimensions: ...
    @staticmethod
    def ALess_s() -> Units_Dimensions: ...
    @staticmethod
    def ALuminousIntensity_s() -> Units_Dimensions: ...
    @staticmethod
    def AMass_s() -> Units_Dimensions: ...
    @staticmethod
    def APlaneAngle_s() -> Units_Dimensions: ...
    @staticmethod
    def ASolidAngle_s() -> Units_Dimensions: 
        """
        Returns the basic dimensions.
        """
    @staticmethod
    def AThermodynamicTemperature_s() -> Units_Dimensions: ...
    @staticmethod
    def ATime_s() -> Units_Dimensions: ...
    def AmountOfSubstance(self) -> float: 
        """
        Returns the power of quantity of material (mole) stored in the dimensions.

        Returns the power of quantity of material (mole) stored in the dimensions.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Divide(self,adimensions : Units_Dimensions) -> Units_Dimensions: 
        """
        Creates and returns a new Dimensions object which is the result of the division of <me> by <adimensions>.
        """
    def Dump(self,ashift : int) -> None: 
        """
        Useful for degugging.
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def ElectricCurrent(self) -> float: 
        """
        Returns the power of electrical intensity (current) stored in the dimensions.

        Returns the power of electrical intensity (current) stored in the dimensions.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEqual(self,adimensions : Units_Dimensions) -> bool: 
        """
        Returns true if <me> and <adimensions> have the same dimensions, false otherwise.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsNotEqual(self,adimensions : Units_Dimensions) -> bool: 
        """
        Returns false if <me> and <adimensions> have the same dimensions, true otherwise.
        """
    def Length(self) -> float: 
        """
        Returns the power of length stored in the dimensions.

        Returns the power of length stored in the dimensions.
        """
    def LuminousIntensity(self) -> float: 
        """
        Returns the power of light intensity stored in the dimensions.

        Returns the power of light intensity stored in the dimensions.
        """
    def Mass(self) -> float: 
        """
        Returns the power of mass stored in the dimensions.

        Returns the power of mass stored in the dimensions.
        """
    def Multiply(self,adimensions : Units_Dimensions) -> Units_Dimensions: 
        """
        Creates and returns a new Dimensions object which is the result of the multiplication of <me> and <adimensions>.
        """
    def PlaneAngle(self) -> float: 
        """
        Returns the power of plane angle stored in the dimensions.

        Returns the power of plane angle stored in the dimensions.
        """
    def Power(self,anexponent : float) -> Units_Dimensions: 
        """
        Creates and returns a new Dimensions object which is the result of the power of <me> and <anexponent>.
        """
    def Quantity(self) -> str: 
        """
        Returns the quantity string of the dimension
        """
    def SolidAngle(self) -> float: 
        """
        Returns the power of solid angle stored in the dimensions.

        Returns the power of solid angle stored in the dimensions.
        """
    def ThermodynamicTemperature(self) -> float: 
        """
        Returns the power of temperature stored in the dimensions.

        Returns the power of temperature stored in the dimensions.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Time(self) -> float: 
        """
        Returns the power of time stored in the dimensions.

        Returns the power of time stored in the dimensions.
        """
    def __init__(self,amass : float,alength : float,atime : float,anelectriccurrent : float,athermodynamictemperature : float,anamountofsubstance : float,aluminousintensity : float,aplaneangle : float,asolidangle : float) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_Explorer():
    """
    This class provides all the services to explore UnitsSystem or UnitsDictionary.
    """
    @overload
    def Init(self,aunitssystem : Units_UnitsSystem) -> None: 
        """
        Initializes the instance of the class with the UnitsSystem <aunitssystem>.

        Initializes the instance of the class with the UnitsDictionary <aunitsdictionary>.

        Initializes the instance of the class with the UnitsSystem <aunitssystem> and positioned at the quantity <aquantity>.

        Initializes the instance of the class with the UnitsDictionary <aunitsdictionary> and positioned at the quantity <aquantity>.
        """
    @overload
    def Init(self,aunitsdictionary : Units_UnitsDictionary) -> None: ...
    @overload
    def Init(self,aunitssystem : Units_UnitsSystem,aquantity : str) -> None: ...
    @overload
    def Init(self,aunitsdictionary : Units_UnitsDictionary,aquantity : str) -> None: ...
    def IsActive(self) -> bool: 
        """
        If the units system to explore is a user system, returns True if the current unit is active, False otherwise.
        """
    def MoreQuantity(self) -> bool: 
        """
        Returns True if there is another Quantity to explore, False otherwise.
        """
    def MoreUnit(self) -> bool: 
        """
        Returns True if there is another Unit to explore, False otherwise.
        """
    def NextQuantity(self) -> None: 
        """
        Sets the next Quantity current.
        """
    def NextUnit(self) -> None: 
        """
        Sets the next Unit current.
        """
    def Quantity(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the name of the current Quantity.
        """
    def Unit(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the name of the current unit.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,aunitssystem : Units_UnitsSystem) -> None: ...
    @overload
    def __init__(self,aunitsdictionary : Units_UnitsDictionary) -> None: ...
    @overload
    def __init__(self,aunitssystem : Units_UnitsSystem,aquantity : str) -> None: ...
    @overload
    def __init__(self,aunitsdictionary : Units_UnitsDictionary,aquantity : str) -> None: ...
    pass
class Units_Lexicon(OCP.Standard.Standard_Transient):
    """
    This class defines a lexicon useful to analyse and recognize the different key words included in a sentence. The lexicon is stored in a sequence of tokens.This class defines a lexicon useful to analyse and recognize the different key words included in a sentence. The lexicon is stored in a sequence of tokens.This class defines a lexicon useful to analyse and recognize the different key words included in a sentence. The lexicon is stored in a sequence of tokens.
    """
    def AddToken(self,aword : str,amean : str,avalue : float) -> None: 
        """
        Adds to the lexicon a new token with <aword>, <amean>, <avalue> as arguments. If there is already a token with the field <theword> equal to <aword>, the existing token is updated.
        """
    def Creates(self) -> None: 
        """
        Reads the file <afilename> to create a sequence of tokens stored in <thesequenceoftokens>.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Dump(self) -> None: 
        """
        Useful for debugging.

        Useful for debugging.
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Sequence(self) -> Units_TokensSequence: 
        """
        Returns the first item of the sequence of tokens.

        Returns the first item of the sequence of tokens.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_Sentence():
    """
    This class describes all the methods to create and compute an expression contained in a string.
    """
    def Dump(self) -> None: 
        """
        Useful for debugging.

        Useful for debugging.
        """
    def Evaluate(self) -> Units_Token: 
        """
        Computes and returns in a token the result of the expression.
        """
    def IsDone(self) -> bool: 
        """
        Return True if number of created tokens > 0 (i.e creation of sentence is successful)

        Return True if number of created tokens > 0 (i.e creation of sentence is successful)
        """
    @overload
    def Sequence(self) -> Units_TokensSequence: 
        """
        Returns <thesequenceoftokens>.

        Sets the field <thesequenceoftokens> to <asequenceoftokens>.

        Returns <thesequenceoftokens>.

        Sets the field <thesequenceoftokens> to <asequenceoftokens>.
        """
    @overload
    def Sequence(self,asequenceoftokens : Units_TokensSequence) -> None: ...
    def SetConstants(self) -> None: 
        """
        For each constant encountered, sets the value.
        """
    def __init__(self,alexicon : Units_Lexicon,astring : str) -> None: ...
    pass
class Units_Measurement():
    """
    This class defines a measurement which is the association of a real value and a unit.
    """
    def Add(self,ameasurement : Units_Measurement) -> Units_Measurement: ...
    def Convert(self,aunit : str) -> None: ...
    @overload
    def Divide(self,ameasurement : Units_Measurement) -> Units_Measurement: 
        """
        Returns a measurement which is the division of <me> by <ameasurement>.

        Returns a measurement which is the division of <me> by the constant <avalue>.
        """
    @overload
    def Divide(self,avalue : float) -> Units_Measurement: ...
    def Dump(self) -> None: 
        """
        Useful for debugging.
        """
    def Fractional(self) -> Units_Measurement: 
        """
        Returns a Measurement object with the fractional value of the measurement contained in <me>.
        """
    def HasToken(self) -> bool: ...
    def Integer(self) -> Units_Measurement: 
        """
        Returns a Measurement object with the integer value of the measurement contained in <me>.
        """
    def Measurement(self) -> float: 
        """
        Returns the value of the measurement.
        """
    @overload
    def Multiply(self,ameasurement : Units_Measurement) -> Units_Measurement: 
        """
        Returns a measurement which is the multiplication of <me> and <ameasurement>.

        Returns a measurement which is the multiplication of <me> with the value <avalue>.
        """
    @overload
    def Multiply(self,avalue : float) -> Units_Measurement: ...
    def Power(self,anexponent : float) -> Units_Measurement: 
        """
        Returns a measurement which is <me> powered <anexponent>.
        """
    def Subtract(self,ameasurement : Units_Measurement) -> Units_Measurement: ...
    def Token(self) -> Units_Token: 
        """
        Returns the token contained in <me>.
        """
    def __add__(self,ameasurement : Units_Measurement) -> Units_Measurement: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,avalue : float,atoken : Units_Token) -> None: ...
    @overload
    def __init__(self,avalue : float,aunit : str) -> None: ...
    @overload
    def __mul__(self,ameasurement : Units_Measurement) -> Units_Measurement: ...
    @overload
    def __mul__(self,avalue : float) -> Units_Measurement: ...
    @overload
    def __rmul__(self,ameasurement : Units_Measurement) -> Units_Measurement: ...
    @overload
    def __rmul__(self,avalue : float) -> Units_Measurement: ...
    def __sub__(self,ameasurement : Units_Measurement) -> Units_Measurement: ...
    @overload
    def __truediv__(self,ameasurement : Units_Measurement) -> Units_Measurement: ...
    @overload
    def __truediv__(self,avalue : float) -> Units_Measurement: ...
    pass
class Units_NoSuchType(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Units', '__weakref__': <attribute '__weakref__' of 'Units_NoSuchType' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Units_NoSuchType' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Units_NoSuchUnit(Exception, BaseException):
    class type():
        pass
    __cause__: getset_descriptor # value = <attribute '__cause__' of 'BaseException' objects>
    __context__: getset_descriptor # value = <attribute '__context__' of 'BaseException' objects>
    __dict__: mappingproxy # value = mappingproxy({'__module__': 'OCP.Units', '__weakref__': <attribute '__weakref__' of 'Units_NoSuchUnit' objects>, '__doc__': None})
    __suppress_context__: member_descriptor # value = <member '__suppress_context__' of 'BaseException' objects>
    __traceback__: getset_descriptor # value = <attribute '__traceback__' of 'BaseException' objects>
    __weakref__: getset_descriptor # value = <attribute '__weakref__' of 'Units_NoSuchUnit' objects>
    args: getset_descriptor # value = <attribute 'args' of 'BaseException' objects>
    pass
class Units_QtsSequence(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : Units_Quantity) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : Units_QtsSequence) -> None: ...
    def Assign(self,theOther : Units_QtsSequence) -> Units_QtsSequence: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> Units_Quantity: 
        """
        First item access
        """
    def ChangeLast(self) -> Units_Quantity: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> Units_Quantity: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> Units_Quantity: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : Units_QtsSequence) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : Units_Quantity) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : Units_Quantity) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : Units_QtsSequence) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> Units_Quantity: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : Units_Quantity) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : Units_QtsSequence) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : Units_Quantity) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : Units_QtsSequence) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> Units_Quantity: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> Units_Quantity: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : Units_QtsSequence) -> None: ...
    def __iter__(self) -> Iterator[Units_Quantity]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class Units_QuantitiesSequence(Units_QtsSequence, OCP.NCollection.NCollection_BaseSequence, OCP.Standard.Standard_Transient):
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : Units_Quantity) -> None: ...
    @overload
    def Append(self,theSequence : Units_QtsSequence) -> None: ...
    def Assign(self,theOther : Units_QtsSequence) -> Units_QtsSequence: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> Units_Quantity: 
        """
        First item access
        """
    def ChangeLast(self) -> Units_Quantity: 
        """
        Last item access
        """
    def ChangeSequence(self) -> Units_QtsSequence: ...
    def ChangeValue(self,theIndex : int) -> Units_Quantity: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> Units_Quantity: 
        """
        First item access
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : Units_QtsSequence) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : Units_Quantity) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : Units_Quantity) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : Units_QtsSequence) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> Units_Quantity: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : Units_Quantity) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : Units_QtsSequence) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def Sequence(self) -> Units_QtsSequence: ...
    def SetValue(self,theIndex : int,theItem : Units_Quantity) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : Units_QtsSequence) -> None: 
        """
        Split in two sequences
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> Units_Quantity: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> Units_Quantity: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theOther : Units_QtsSequence) -> None: ...
    def __iter__(self) -> Iterator[Units_Quantity]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_Quantity(OCP.Standard.Standard_Transient):
    """
    This class stores in its field all the possible units of all the unit systems for a given physical quantity. Each unit's value is expressed in the S.I. unit system.This class stores in its field all the possible units of all the unit systems for a given physical quantity. Each unit's value is expressed in the S.I. unit system.This class stores in its field all the possible units of all the unit systems for a given physical quantity. Each unit's value is expressed in the S.I. unit system.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Dimensions(self) -> Units_Dimensions: 
        """
        Returns the physical dimensions of the quantity.

        Returns the physical dimensions of the quantity.
        """
    def Dump(self,ashift : int,alevel : int) -> None: 
        """
        Useful for debugging.
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEqual(self,astring : str) -> bool: 
        """
        Returns True if the name of the Quantity <me> is equal to <astring>, False otherwise.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Name(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns in a AsciiString from TCollection the name of the quantity.

        Returns in a AsciiString from TCollection the name of the quantity.
        """
    def Sequence(self) -> Units_UnitsSequence: 
        """
        Returns <theunitssequence>, which is the sequence of all the units stored for this physical quantity.

        Returns <theunitssequence>, which is the sequence of all the units stored for this physical quantity.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self,aname : str,adimensions : Units_Dimensions,aunitssequence : Units_UnitsSequence) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_MathSentence(Units_Sentence):
    """
    This class defines all the methods to create and compute an algebraic formula.
    """
    def Dump(self) -> None: 
        """
        Useful for debugging.

        Useful for debugging.
        """
    def Evaluate(self) -> Units_Token: 
        """
        Computes and returns in a token the result of the expression.
        """
    def IsDone(self) -> bool: 
        """
        Return True if number of created tokens > 0 (i.e creation of sentence is successful)

        Return True if number of created tokens > 0 (i.e creation of sentence is successful)
        """
    @overload
    def Sequence(self) -> Units_TokensSequence: 
        """
        Returns <thesequenceoftokens>.

        Sets the field <thesequenceoftokens> to <asequenceoftokens>.

        Returns <thesequenceoftokens>.

        Sets the field <thesequenceoftokens> to <asequenceoftokens>.
        """
    @overload
    def Sequence(self,asequenceoftokens : Units_TokensSequence) -> None: ...
    def SetConstants(self) -> None: 
        """
        For each constant encountered, sets the value.
        """
    def __init__(self,astring : str) -> None: ...
    pass
class Units_Token(OCP.Standard.Standard_Transient):
    """
    This class defines an elementary word contained in a Sentence object.This class defines an elementary word contained in a Sentence object.This class defines an elementary word contained in a Sentence object.
    """
    @overload
    def Add(self,aninteger : int) -> Units_Token: 
        """
        Returns a token which is the addition of <me> and another token <atoken>. The addition is possible if and only if the dimensions are the same.
        """
    @overload
    def Add(self,atoken : Units_Token) -> Units_Token: ...
    def Creates(self) -> Units_Token: 
        """
        Creates and returns a token, which is a ShiftedToken.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    @overload
    def Dimensions(self) -> Units_Dimensions: 
        """
        Returns the dimensions of the token <thedimensions>.

        Sets the field <thedimensions> to <adimensions>.

        Returns the dimensions of the token <thedimensions>.
        """
    @overload
    def Dimensions(self,adimensions : Units_Dimensions) -> None: ...
    def Divide(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is the division of <me> by another token <atoken>.
        """
    def Divided(self,avalue : float) -> float: 
        """
        This virtual method is called by the Measurement methods, to compute the measurement during a conversion.
        """
    def Dump(self,ashift : int,alevel : int) -> None: 
        """
        Useful for debugging
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsEqual(self,astring : str) -> bool: 
        """
        Returns true if the field <theword> and the string <astring> are the same, false otherwise.

        Returns true if the field <theword> and the string <theword> contained in the token <atoken> are the same, false otherwise.
        """
    @overload
    def IsEqual(self,atoken : Units_Token) -> bool: ...
    @overload
    def IsGreater(self,astring : str) -> bool: 
        """
        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.

        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.

        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.

        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.
        """
    @overload
    def IsGreater(self,atoken : Units_Token) -> bool: ...
    def IsGreaterOrEqual(self,atoken : Units_Token) -> bool: 
        """
        Returns true if the string <astring> is strictly contained at the beginning of the field <theword> false otherwise.

        Returns true if the string <astring> is strictly contained at the beginning of the field <theword> false otherwise.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsLessOrEqual(self,astring : str) -> bool: 
        """
        Returns true if the field <theword> is strictly contained at the beginning of the string <astring>, false otherwise.

        Returns true if the field <theword> is strictly contained at the beginning of the string <astring>, false otherwise.
        """
    @overload
    def IsNotEqual(self,astring : str) -> bool: 
        """
        Returns false if the field <theword> and the string <astring> are the same, true otherwise.

        Returns false if the field <theword> and the string <theword> contained in the token <atoken> are the same, true otherwise.

        Returns false if the field <theword> and the string <astring> are the same, true otherwise.

        Returns false if the field <theword> and the string <theword> contained in the token <atoken> are the same, true otherwise.
        """
    @overload
    def IsNotEqual(self,atoken : Units_Token) -> bool: ...
    def Length(self) -> int: 
        """
        Returns the length of the word.
        """
    @overload
    def Mean(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the significance of the word <theword>, which is in the field <themean>.

        Sets the field <themean> to <amean>.

        Returns the significance of the word <theword>, which is in the field <themean>.

        Sets the field <themean> to <amean>.
        """
    @overload
    def Mean(self,amean : str) -> None: ...
    def Multiplied(self,avalue : float) -> float: 
        """
        This virtual method is called by the Measurement methods, to compute the measurement during a conversion.
        """
    def Multiply(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is the product of <me> and another token <atoken>.
        """
    @overload
    def Power(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is <me> to the power of another token <atoken>. The computation is possible only if <atoken> is a dimensionless constant.

        Returns a token which is <me> to the power of <anexponent>.
        """
    @overload
    def Power(self,anexponent : float) -> Units_Token: ...
    def Subtract(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is the subtraction of <me> and another token <atoken>. The subtraction is possible if and only if the dimensions are the same.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,amean : str) -> None: 
        """
        Updates the token <me> with the additional signification <amean> by concatenation of the two strings <themean> and <amean>. If the two significations are the same , an information message is written in the output device.
        """
    @overload
    def Value(self) -> float: 
        """
        Returns the value stored in the field <thevalue>.

        Sets the field <thevalue> to <avalue>.

        Returns the value stored in the field <thevalue>.

        Sets the field <thevalue> to <avalue>.
        """
    @overload
    def Value(self,avalue : float) -> None: ...
    @overload
    def Word(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the string <theword>

        Sets the field <theword> to <aword>.

        Returns the string <theword>

        Sets the field <theword> to <aword>.
        """
    @overload
    def Word(self,aword : str) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,aword : str) -> None: ...
    @overload
    def __init__(self,atoken : Units_Token) -> None: ...
    @overload
    def __init__(self,aword : str,amean : str) -> None: ...
    @overload
    def __init__(self,aword : str,amean : str,avalue : float) -> None: ...
    @overload
    def __init__(self,aword : str,amean : str,avalue : float,adimension : Units_Dimensions) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_Unit(OCP.Standard.Standard_Transient):
    """
    This class defines an elementary word contained in a physical quantity.This class defines an elementary word contained in a physical quantity.This class defines an elementary word contained in a physical quantity.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Dump(self,ashift : int,alevel : int) -> None: 
        """
        Useful for debugging
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEqual(self,astring : str) -> bool: 
        """
        Compares all the symbols linked within <me> with the name of <atoken>, and returns True if there is one symbol equal to the name, False otherwise.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Name(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the name of the unit <thename>

        Returns the name of the unit <thename>
        """
    @overload
    def Quantity(self) -> Units_Quantity: 
        """
        Returns <thequantity> contained in <me>.

        Sets the physical Quantity <aquantity> to <me>.

        Returns <thequantity> contained in <me>.

        Sets the physical Quantity <aquantity> to <me>.
        """
    @overload
    def Quantity(self,aquantity : Units_Quantity) -> None: ...
    def Symbol(self,asymbol : str) -> None: 
        """
        Adds a new symbol <asymbol> attached to <me>.
        """
    def SymbolsSequence(self) -> OCP.TColStd.TColStd_HSequenceOfHAsciiString: 
        """
        Returns the sequence of symbols <thesymbolssequence>

        Returns the sequence of symbols <thesymbolssequence>
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Token(self) -> Units_Token: 
        """
        Starting with <me>, returns a new Token object.
        """
    @overload
    def Value(self) -> float: 
        """
        Returns the value in relation with the International System of Units.

        Sets the value <avalue> to <me>.

        Returns the value in relation with the International System of Units.

        Sets the value <avalue> to <me>.
        """
    @overload
    def Value(self,avalue : float) -> None: ...
    @overload
    def __init__(self,aname : str,asymbol : str,avalue : float,aquantity : Units_Quantity) -> None: ...
    @overload
    def __init__(self,aname : str,asymbol : str) -> None: ...
    @overload
    def __init__(self,aname : str) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_TksSequence(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : Units_Token) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : Units_TksSequence) -> None: ...
    def Assign(self,theOther : Units_TksSequence) -> Units_TksSequence: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> Units_Token: 
        """
        First item access
        """
    def ChangeLast(self) -> Units_Token: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> Units_Token: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> Units_Token: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : Units_TksSequence) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : Units_Token) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : Units_Token) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : Units_TksSequence) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> Units_Token: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : Units_Token) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : Units_TksSequence) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : Units_Token) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : Units_TksSequence) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> Units_Token: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> Units_Token: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : Units_TksSequence) -> None: ...
    def __iter__(self) -> Iterator[Units_Token]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class Units_ShiftedToken(Units_Token, OCP.Standard.Standard_Transient):
    """
    The ShiftedToken class inherits from Token and describes tokens which have a gap in addition of the multiplicative factor. This kind of token allows the description of linear functions which do not pass through the origin, of the form :The ShiftedToken class inherits from Token and describes tokens which have a gap in addition of the multiplicative factor. This kind of token allows the description of linear functions which do not pass through the origin, of the form :The ShiftedToken class inherits from Token and describes tokens which have a gap in addition of the multiplicative factor. This kind of token allows the description of linear functions which do not pass through the origin, of the form :
    """
    @overload
    def Add(self,aninteger : int) -> Units_Token: 
        """
        Returns a token which is the addition of <me> and another token <atoken>. The addition is possible if and only if the dimensions are the same.
        """
    @overload
    def Add(self,atoken : Units_Token) -> Units_Token: ...
    def Creates(self) -> Units_Token: 
        """
        Creates and returns a token, which is a ShiftedToken.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    @overload
    def Dimensions(self) -> Units_Dimensions: 
        """
        Returns the dimensions of the token <thedimensions>.

        Sets the field <thedimensions> to <adimensions>.

        Returns the dimensions of the token <thedimensions>.
        """
    @overload
    def Dimensions(self,adimensions : Units_Dimensions) -> None: ...
    def Divide(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is the division of <me> by another token <atoken>.
        """
    def Divided(self,avalue : float) -> float: 
        """
        This virtual method is called by the Measurement methods, to compute the measurement during a conversion.
        """
    def Dump(self,ashift : int,alevel : int) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsEqual(self,astring : str) -> bool: 
        """
        Returns true if the field <theword> and the string <astring> are the same, false otherwise.

        Returns true if the field <theword> and the string <theword> contained in the token <atoken> are the same, false otherwise.
        """
    @overload
    def IsEqual(self,atoken : Units_Token) -> bool: ...
    @overload
    def IsGreater(self,astring : str) -> bool: 
        """
        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.

        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.

        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.

        Returns false if the field <theword> is strictly contained at the beginning of the string <astring>, true otherwise.
        """
    @overload
    def IsGreater(self,atoken : Units_Token) -> bool: ...
    def IsGreaterOrEqual(self,atoken : Units_Token) -> bool: 
        """
        Returns true if the string <astring> is strictly contained at the beginning of the field <theword> false otherwise.

        Returns true if the string <astring> is strictly contained at the beginning of the field <theword> false otherwise.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsLessOrEqual(self,astring : str) -> bool: 
        """
        Returns true if the field <theword> is strictly contained at the beginning of the string <astring>, false otherwise.

        Returns true if the field <theword> is strictly contained at the beginning of the string <astring>, false otherwise.
        """
    @overload
    def IsNotEqual(self,astring : str) -> bool: 
        """
        Returns false if the field <theword> and the string <astring> are the same, true otherwise.

        Returns false if the field <theword> and the string <theword> contained in the token <atoken> are the same, true otherwise.

        Returns false if the field <theword> and the string <astring> are the same, true otherwise.

        Returns false if the field <theword> and the string <theword> contained in the token <atoken> are the same, true otherwise.
        """
    @overload
    def IsNotEqual(self,atoken : Units_Token) -> bool: ...
    def Length(self) -> int: 
        """
        Returns the length of the word.
        """
    @overload
    def Mean(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the significance of the word <theword>, which is in the field <themean>.

        Sets the field <themean> to <amean>.

        Returns the significance of the word <theword>, which is in the field <themean>.

        Sets the field <themean> to <amean>.
        """
    @overload
    def Mean(self,amean : str) -> None: ...
    def Move(self) -> float: 
        """
        Returns the gap <themove>
        """
    def Multiplied(self,avalue : float) -> float: 
        """
        This virtual method is called by the Measurement methods, to compute the measurement during a conversion.
        """
    def Multiply(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is the product of <me> and another token <atoken>.
        """
    @overload
    def Power(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is <me> to the power of another token <atoken>. The computation is possible only if <atoken> is a dimensionless constant.

        Returns a token which is <me> to the power of <anexponent>.
        """
    @overload
    def Power(self,anexponent : float) -> Units_Token: ...
    def Subtract(self,atoken : Units_Token) -> Units_Token: 
        """
        Returns a token which is the subtraction of <me> and another token <atoken>. The subtraction is possible if and only if the dimensions are the same.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,amean : str) -> None: 
        """
        Updates the token <me> with the additional signification <amean> by concatenation of the two strings <themean> and <amean>. If the two significations are the same , an information message is written in the output device.
        """
    @overload
    def Value(self) -> float: 
        """
        Returns the value stored in the field <thevalue>.

        Sets the field <thevalue> to <avalue>.

        Returns the value stored in the field <thevalue>.

        Sets the field <thevalue> to <avalue>.
        """
    @overload
    def Value(self,avalue : float) -> None: ...
    @overload
    def Word(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the string <theword>

        Sets the field <theword> to <aword>.

        Returns the string <theword>

        Sets the field <theword> to <aword>.
        """
    @overload
    def Word(self,aword : str) -> None: ...
    def __init__(self,aword : str,amean : str,avalue : float,amove : float,adimensions : Units_Dimensions) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_TokensSequence(Units_TksSequence, OCP.NCollection.NCollection_BaseSequence, OCP.Standard.Standard_Transient):
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : Units_Token) -> None: ...
    @overload
    def Append(self,theSequence : Units_TksSequence) -> None: ...
    def Assign(self,theOther : Units_TksSequence) -> Units_TksSequence: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> Units_Token: 
        """
        First item access
        """
    def ChangeLast(self) -> Units_Token: 
        """
        Last item access
        """
    def ChangeSequence(self) -> Units_TksSequence: ...
    def ChangeValue(self,theIndex : int) -> Units_Token: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> Units_Token: 
        """
        First item access
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : Units_TksSequence) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : Units_Token) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : Units_Token) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : Units_TksSequence) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> Units_Token: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : Units_Token) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : Units_TksSequence) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def Sequence(self) -> Units_TksSequence: ...
    def SetValue(self,theIndex : int,theItem : Units_Token) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : Units_TksSequence) -> None: 
        """
        Split in two sequences
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> Units_Token: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> Units_Token: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theOther : Units_TksSequence) -> None: ...
    def __iter__(self) -> Iterator[Units_Token]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_ShiftedUnit(Units_Unit, OCP.Standard.Standard_Transient):
    """
    This class is useful to describe units with a shifted origin in relation to another unit. A well known example is the Celsius degrees in relation to Kelvin degrees. The shift of the Celsius origin is 273.15 Kelvin degrees.This class is useful to describe units with a shifted origin in relation to another unit. A well known example is the Celsius degrees in relation to Kelvin degrees. The shift of the Celsius origin is 273.15 Kelvin degrees.This class is useful to describe units with a shifted origin in relation to another unit. A well known example is the Celsius degrees in relation to Kelvin degrees. The shift of the Celsius origin is 273.15 Kelvin degrees.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Dump(self,ashift : int,alevel : int) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEqual(self,astring : str) -> bool: 
        """
        Compares all the symbols linked within <me> with the name of <atoken>, and returns True if there is one symbol equal to the name, False otherwise.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @overload
    def Move(self,amove : float) -> None: 
        """
        Sets the field <themove> to <amove>

        Returns the shifted value <themove>.
        """
    @overload
    def Move(self) -> float: ...
    def Name(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the name of the unit <thename>

        Returns the name of the unit <thename>
        """
    @overload
    def Quantity(self) -> Units_Quantity: 
        """
        Returns <thequantity> contained in <me>.

        Sets the physical Quantity <aquantity> to <me>.

        Returns <thequantity> contained in <me>.

        Sets the physical Quantity <aquantity> to <me>.
        """
    @overload
    def Quantity(self,aquantity : Units_Quantity) -> None: ...
    def Symbol(self,asymbol : str) -> None: 
        """
        Adds a new symbol <asymbol> attached to <me>.
        """
    def SymbolsSequence(self) -> OCP.TColStd.TColStd_HSequenceOfHAsciiString: 
        """
        Returns the sequence of symbols <thesymbolssequence>

        Returns the sequence of symbols <thesymbolssequence>
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Token(self) -> Units_Token: 
        """
        This redefined method returns a ShiftedToken object.
        """
    @overload
    def Value(self) -> float: 
        """
        Returns the value in relation with the International System of Units.

        Sets the value <avalue> to <me>.

        Returns the value in relation with the International System of Units.

        Sets the value <avalue> to <me>.
        """
    @overload
    def Value(self,avalue : float) -> None: ...
    @overload
    def __init__(self,aname : str,asymbol : str,avalue : float,amove : float,aquantity : Units_Quantity) -> None: ...
    @overload
    def __init__(self,aname : str,asymbol : str) -> None: ...
    @overload
    def __init__(self,aname : str) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_UnitSentence(Units_Sentence):
    """
    This class describes all the facilities to manipulate and compute units contained in a string expression.
    """
    def Analyse(self) -> None: 
        """
        Analyzes the sequence of tokens created by the constructor to find the true significance of each token.
        """
    def Dump(self) -> None: 
        """
        Useful for debugging.

        Useful for debugging.
        """
    def Evaluate(self) -> Units_Token: 
        """
        Computes and returns in a token the result of the expression.
        """
    def IsDone(self) -> bool: 
        """
        Return True if number of created tokens > 0 (i.e creation of sentence is successful)

        Return True if number of created tokens > 0 (i.e creation of sentence is successful)
        """
    @overload
    def Sequence(self) -> Units_TokensSequence: 
        """
        Returns <thesequenceoftokens>.

        Sets the field <thesequenceoftokens> to <asequenceoftokens>.

        Returns <thesequenceoftokens>.

        Sets the field <thesequenceoftokens> to <asequenceoftokens>.
        """
    @overload
    def Sequence(self,asequenceoftokens : Units_TokensSequence) -> None: ...
    def SetConstants(self) -> None: 
        """
        For each constant encountered, sets the value.
        """
    def SetUnits(self,aquantitiessequence : Units_QuantitiesSequence) -> None: 
        """
        For each token which represents a unit, finds in the sequence of physical quantities all the characteristics of the unit found.
        """
    @overload
    def __init__(self,astring : str) -> None: ...
    @overload
    def __init__(self,astring : str,aquantitiessequence : Units_QuantitiesSequence) -> None: ...
    pass
class Units_UnitsDictionary(OCP.Standard.Standard_Transient):
    """
    This class creates a dictionary of all the units you want to know.This class creates a dictionary of all the units you want to know.This class creates a dictionary of all the units you want to know.
    """
    def ActiveUnit(self,aquantity : str) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns for <aquantity> the active unit.
        """
    def Creates(self) -> None: 
        """
        Returns a UnitsDictionary object which contains the sequence of all the units you want to consider, physical quantity by physical quantity.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    @overload
    def Dump(self,alevel : int) -> None: 
        """
        Dumps only the sequence of quantities without the units if <alevel> is equal to zero, and for each quantity all the units stored if <alevel> is equal to one.

        Dumps for a designated physical dimensions <adimensions> all the previously stored units.

        Dumps only the sequence of quantities without the units if <alevel> is equal to zero, and for each quantity all the units stored if <alevel> is equal to one.

        Dumps for a designated physical dimensions <adimensions> all the previously stored units.
        """
    @overload
    def Dump(self,adimensions : Units_Dimensions) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Sequence(self) -> Units_QuantitiesSequence: 
        """
        Returns the head of the sequence of physical quantities.

        Returns the head of the sequence of physical quantities.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_UnitsLexicon(Units_Lexicon, OCP.Standard.Standard_Transient):
    """
    This class defines a lexicon useful to analyse and recognize the different key words included in a sentence. The lexicon is stored in a sequence of tokens.This class defines a lexicon useful to analyse and recognize the different key words included in a sentence. The lexicon is stored in a sequence of tokens.This class defines a lexicon useful to analyse and recognize the different key words included in a sentence. The lexicon is stored in a sequence of tokens.
    """
    def AddToken(self,aword : str,amean : str,avalue : float) -> None: 
        """
        Adds to the lexicon a new token with <aword>, <amean>, <avalue> as arguments. If there is already a token with the field <theword> equal to <aword>, the existing token is updated.
        """
    def Creates(self,amode : bool=True) -> None: 
        """
        Reads the files <afilename1> and <afilename2> to create a sequence of tokens stored in <thesequenceoftokens>.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Dump(self) -> None: 
        """
        Useful for debugging.

        Useful for debugging.
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Sequence(self) -> Units_TokensSequence: 
        """
        Returns the first item of the sequence of tokens.

        Returns the first item of the sequence of tokens.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_UtsSequence(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : Units_Unit) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : Units_UtsSequence) -> None: ...
    def Assign(self,theOther : Units_UtsSequence) -> Units_UtsSequence: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> Units_Unit: 
        """
        First item access
        """
    def ChangeLast(self) -> Units_Unit: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> Units_Unit: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> Units_Unit: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : Units_UtsSequence) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : Units_Unit) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : Units_Unit) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : Units_UtsSequence) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> Units_Unit: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : Units_Unit) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : Units_UtsSequence) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : Units_Unit) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : Units_UtsSequence) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> Units_Unit: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> Units_Unit: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : Units_UtsSequence) -> None: ...
    def __iter__(self) -> Iterator[Units_Unit]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class Units_UnitsSystem(OCP.Standard.Standard_Transient):
    """
    This class allows the user to define his own system of units.This class allows the user to define his own system of units.This class allows the user to define his own system of units.
    """
    def Activate(self,aquantity : str,aunit : str) -> None: 
        """
        Specifies for <aquantity> the unit <aunit> used.
        """
    def Activates(self) -> None: 
        """
        Activates the first unit of all defined system quantities
        """
    def ActiveUnit(self,aquantity : str) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns for <aquantity> the active unit.
        """
    def ActiveUnitsSequence(self) -> OCP.TColStd.TColStd_HSequenceOfInteger: 
        """
        Returns a sequence of integer in correspondence with the sequence of quantities, which indicates, for each redefined quantity, the index into the sequence of units, of the active unit.
        """
    def ConvertSIValueToUserSystem(self,aquantity : str,avalue : float) -> float: 
        """
        Converts the real value <avalue> from the S.I. system of units to the user system of units. <aquantity> is the physical dimensions of the measurement.
        """
    def ConvertUserSystemValueToSI(self,aquantity : str,avalue : float) -> float: 
        """
        Converts the real value <avalue> from the user system of units to the S.I. system of units. <aquantity> is the physical dimensions of the measurement.
        """
    def ConvertValueToUserSystem(self,aquantity : str,avalue : float,aunit : str) -> float: 
        """
        Converts a real value <avalue> from the unit <aunit> belonging to the physical dimensions <aquantity> to the corresponding unit of the user system.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Dump(self) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEmpty(self) -> bool: 
        """
        Returns TRUE if no units has been defined in the system.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def QuantitiesSequence(self) -> Units_QuantitiesSequence: 
        """
        Returns the sequence of refined quantities.
        """
    def Remove(self,aquantity : str,aunit : str) -> None: 
        """
        Removes for <aquantity> the unit <aunit> used.
        """
    def Specify(self,aquantity : str,aunit : str) -> None: 
        """
        Specifies for <aquantity> the unit <aunit> used.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,aName : str,Verbose : bool=False) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Units_UnitsSequence(Units_UtsSequence, OCP.NCollection.NCollection_BaseSequence, OCP.Standard.Standard_Transient):
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : Units_Unit) -> None: ...
    @overload
    def Append(self,theSequence : Units_UtsSequence) -> None: ...
    def Assign(self,theOther : Units_UtsSequence) -> Units_UtsSequence: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> Units_Unit: 
        """
        First item access
        """
    def ChangeLast(self) -> Units_Unit: 
        """
        Last item access
        """
    def ChangeSequence(self) -> Units_UtsSequence: ...
    def ChangeValue(self,theIndex : int) -> Units_Unit: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> Units_Unit: 
        """
        First item access
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : Units_UtsSequence) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : Units_Unit) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : Units_Unit) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : Units_UtsSequence) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> Units_Unit: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : Units_Unit) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : Units_UtsSequence) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def Sequence(self) -> Units_UtsSequence: ...
    def SetValue(self,theIndex : int,theItem : Units_Unit) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : Units_UtsSequence) -> None: 
        """
        Split in two sequences
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> Units_Unit: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> Units_Unit: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theOther : Units_UtsSequence) -> None: ...
    def __iter__(self) -> Iterator[Units_Unit]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
@overload
def __add__(arg0 : Units_Token,arg1 : int) -> Units_Token:
    pass
@overload
def __add__(arg0 : Units_Token,arg1 : Units_Token) -> Units_Token:
    pass
@overload
def __mul__(arg0 : Units_Dimensions,arg1 : Units_Dimensions) -> Units_Dimensions:
    pass
@overload
def __mul__(arg0 : Units_Token,arg1 : Units_Token) -> Units_Token:
    pass
@overload
def __rmul__(arg0 : Units_Dimensions,arg1 : Units_Dimensions) -> Units_Dimensions:
    pass
@overload
def __rmul__(arg0 : Units_Token,arg1 : Units_Token) -> Units_Token:
    pass
def __sub__(arg0 : Units_Token,arg1 : Units_Token) -> Units_Token:
    pass
@overload
def __truediv__(arg0 : Units_Dimensions,arg1 : Units_Dimensions) -> Units_Dimensions:
    pass
@overload
def __truediv__(arg0 : Units_Token,arg1 : Units_Token) -> Units_Token:
    pass
@overload
def pow(arg0 : Units_Dimensions,arg1 : float) -> Units_Dimensions:
    pass
@overload
def pow(arg0 : Units_Token,arg1 : Units_Token) -> Units_Token:
    pass
@overload
def pow(arg0 : Units_Token,arg1 : float) -> Units_Token:
    pass



import OCP.ShapeAlgo
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TColGeom2d
import OCP.ShapeExtend
import OCP.Geom
import OCP.TopoDS
import OCP.ShapeFix
import OCP.Standard
import OCP.GeomAbs
import OCP.ShapeAnalysis
import OCP.Geom2d
import OCP.TColGeom
__all__  = [
"ShapeAlgo",
"ShapeAlgo_AlgoContainer",
"ShapeAlgo_ToolContainer"
]
class ShapeAlgo():
    @staticmethod
    def AlgoContainer_s() -> ShapeAlgo_AlgoContainer: 
        """
        Returns default AlgoContainer
        """
    @staticmethod
    def Init_s() -> None: 
        """
        Provides initerface to the algorithms from Shape Healing. Creates and initializes default AlgoContainer.
        """
    @staticmethod
    def SetAlgoContainer_s(aContainer : ShapeAlgo_AlgoContainer) -> None: 
        """
        Sets default AlgoContainer
        """
    def __init__(self) -> None: ...
    pass
class ShapeAlgo_AlgoContainer(OCP.Standard.Standard_Transient):
    @overload
    def ApproxBSplineCurve(self,bspline : OCP.Geom.Geom_BSplineCurve,seq : OCP.TColGeom.TColGeom_SequenceOfCurve) -> None: ...
    @overload
    def ApproxBSplineCurve(self,bspline : OCP.Geom2d.Geom2d_BSplineCurve,seq : OCP.TColGeom2d.TColGeom2d_SequenceOfCurve) -> None: ...
    @overload
    def C0BSplineToSequenceOfC1BSplineCurve(self,BS : OCP.Geom.Geom_BSplineCurve,seqBS : OCP.TColGeom.TColGeom_HSequenceOfBoundedCurve) -> bool: 
        """
        Converts C0 B-Spline curve into sequence of C1 B-Spline curves. Calls ShapeUpgrade::C0BSplineToSequenceOfC1BSplineCurve.
        """
    @overload
    def C0BSplineToSequenceOfC1BSplineCurve(self,BS : OCP.Geom2d.Geom2d_BSplineCurve,seqBS : OCP.TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve) -> bool: ...
    def C0ShapeToC1Shape(self,shape : OCP.TopoDS.TopoDS_Shape,tol : float) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Converts a shape on C0 geometry into the shape on C1 geometry.
        """
    def ConnectNextWire(self,saw : OCP.ShapeAnalysis.ShapeAnalysis_Wire,nextsewd : OCP.ShapeExtend.ShapeExtend_WireData,maxtol : float,distmin : float,revsewd : bool,revnextsewd : bool) -> bool: 
        """
        Finds the best way to connect and connects <nextsewd> to already built <sewd> (in <saw>). Returns False if <nextsewd> cannot be connected, otherwise - True. <maxtol> specifies the maximum tolerance with which <nextsewd> can be added. <distmin> is used to receive the minimum distance between <nextsewd> and <sewd>. <revsewd> is True if <sewd> has been reversed before connecting. <revnextwd> is True if <nextsewd> has been reversed before connecting. Uses functionality of ShapeAnalysis_Wire.
        """
    def ConvertCurveToBSpline(self,C3D : OCP.Geom.Geom_Curve,First : float,Last : float,Tol3d : float,Continuity : OCP.GeomAbs.GeomAbs_Shape,MaxSegments : int,MaxDegree : int) -> OCP.Geom.Geom_BSplineCurve: 
        """
        Convert Geom_Curve to Geom_BSplineCurve
        """
    def ConvertSurfaceToBSpline(self,surf : OCP.Geom.Geom_Surface,UF : float,UL : float,VF : float,VL : float) -> OCP.Geom.Geom_BSplineSurface: 
        """
        Converts a surface to B-Spline. Uses ShapeConstruct.
        """
    def ConvertToPeriodic(self,surf : OCP.Geom.Geom_Surface) -> OCP.Geom.Geom_Surface: 
        """
        Converts surface to periodic form. Calls ShapeCustom_Surface.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetFaceUVBounds(self,F : OCP.TopoDS.TopoDS_Face) -> tuple[float, float, float, float]: 
        """
        Computes exact UV bounds of all wires on the face
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HomoWires(self,wireIn1 : OCP.TopoDS.TopoDS_Wire,wireIn2 : OCP.TopoDS.TopoDS_Wire,wireOut1 : OCP.TopoDS.TopoDS_Wire,wireOut2 : OCP.TopoDS.TopoDS_Wire,byParam : bool) -> bool: 
        """
        Return 2 wires with the same number of edges. The both Edges number i of these wires have got the same ratio between theirs parameter lengths and their wire parameter lengths.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def OuterWire(self,face : OCP.TopoDS.TopoDS_Face) -> OCP.TopoDS.TopoDS_Wire: 
        """
        Returns the outer wire on the face <Face>.
        """
    def SetToolContainer(self,TC : ShapeAlgo_ToolContainer) -> None: 
        """
        Sets ToolContainer

        Sets ToolContainer
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToolContainer(self) -> ShapeAlgo_ToolContainer: 
        """
        Returns ToolContainer

        Returns ToolContainer
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class ShapeAlgo_ToolContainer(OCP.Standard.Standard_Transient):
    """
    Returns tools used by AlgoContainerReturns tools used by AlgoContainerReturns tools used by AlgoContainer
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def EdgeProjAux(self) -> OCP.ShapeFix.ShapeFix_EdgeProjAux: 
        """
        Returns ShapeFix_EdgeProjAux
        """
    def FixShape(self) -> OCP.ShapeFix.ShapeFix_Shape: 
        """
        Returns ShapeFix_Shape
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass



import OCP.Font
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.gp
import OCP.TColStd
import OCP.Image
import OCP.Standard
import OCP.Graphic3d
import OCP.NCollection
__all__  = [
"Font_FTFont",
"Font_FTFontParams",
"Font_FTLibrary",
"Font_FontAspect",
"Font_FontMgr",
"Font_Hinting",
"Font_NListOfSystemFont",
"Font_Rect",
"Font_StrictLevel",
"Font_SystemFont",
"Font_TextFormatter",
"Font_UnicodeSubset",
"IsEqual",
"Font_FA_Bold",
"Font_FA_BoldItalic",
"Font_FA_Italic",
"Font_FA_Regular",
"Font_FA_Undefined",
"Font_FontAspect_Bold",
"Font_FontAspect_BoldItalic",
"Font_FontAspect_Italic",
"Font_FontAspect_NB",
"Font_FontAspect_Regular",
"Font_FontAspect_UNDEFINED",
"Font_Hinting_ForceAutohint",
"Font_Hinting_Light",
"Font_Hinting_NoAutohint",
"Font_Hinting_Normal",
"Font_Hinting_Off",
"Font_StrictLevel_Aliases",
"Font_StrictLevel_Any",
"Font_StrictLevel_Strict",
"Font_UnicodeSubset_Arabic",
"Font_UnicodeSubset_CJK",
"Font_UnicodeSubset_Korean",
"Font_UnicodeSubset_NB",
"Font_UnicodeSubset_Western"
]
class Font_FTFont(OCP.Standard.Standard_Transient):
    """
    Wrapper over FreeType font. Notice that this class uses internal buffers for loaded glyphs and it is absolutely UNSAFE to load/read glyph from concurrent threads!Wrapper over FreeType font. Notice that this class uses internal buffers for loaded glyphs and it is absolutely UNSAFE to load/read glyph from concurrent threads!
    """
    @overload
    def AdvanceX(self,theUCharNext : str) -> float: 
        """
        Compute horizontal advance to the next character with kerning applied when applicable. Assuming text rendered horizontally.

        Compute horizontal advance to the next character with kerning applied when applicable. Assuming text rendered horizontally.
        """
    @overload
    def AdvanceX(self,theUChar : str,theUCharNext : str) -> float: ...
    @overload
    def AdvanceY(self,theUCharNext : str) -> float: 
        """
        Compute vertical advance to the next character with kerning applied when applicable. Assuming text rendered vertically.

        Compute vertical advance to the next character with kerning applied when applicable. Assuming text rendered vertically.
        """
    @overload
    def AdvanceY(self,theUChar : str,theUCharNext : str) -> float: ...
    def Ascender(self) -> float: 
        """
        Returns vertical distance from the horizontal baseline to the highest character coordinate.
        """
    def BoundingBox(self,theString : OCP.NCollection.NCollection_Utf8String,theAlignX : OCP.Graphic3d.Graphic3d_HorizontalTextAlignment,theAlignY : OCP.Graphic3d.Graphic3d_VerticalTextAlignment) -> Font_Rect: 
        """
        Computes bounding box of the given text using plain-text formatter (Font_TextFormatter). Note that bounding box takes into account the text alignment options. Its corners are relative to the text alignment anchor point, their coordinates can be negative.
        """
    @staticmethod
    def CharSubset_s(theUChar : str) -> Font_UnicodeSubset: 
        """
        Determine Unicode subset for specified character
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Descender(self) -> float: 
        """
        Returns vertical distance from the horizontal baseline to the lowest character coordinate.
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def FindAndCreate_s(theFontName : OCP.TCollection.TCollection_AsciiString,theFontAspect : Font_FontAspect,theParams : Font_FTFontParams,theStrictLevel : Font_StrictLevel=Font_StrictLevel.Font_StrictLevel_Any) -> Font_FTFont: 
        """
        Find the font Initialize the font.
        """
    def FindAndInit(self,theFontName : OCP.TCollection.TCollection_AsciiString,theFontAspect : Font_FontAspect,theParams : Font_FTFontParams,theStrictLevel : Font_StrictLevel=Font_StrictLevel.Font_StrictLevel_Any) -> bool: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GlyphImage(self) -> OCP.Image.Image_PixMap: 
        """
        Returns image plane for currently rendered glyph
        """
    def GlyphMaxSizeX(self,theToIncludeFallback : bool=False) -> int: 
        """
        Returns maximal glyph width in pixels (rendered to bitmap).
        """
    def GlyphMaxSizeY(self,theToIncludeFallback : bool=False) -> int: 
        """
        Returns maximal glyph height in pixels (rendered to bitmap).
        """
    def GlyphRect(self,theRect : Font_Rect) -> None: 
        """
        Retrieve glyph bitmap rectangle
        """
    def GlyphsNumber(self,theToIncludeFallback : bool=False) -> int: 
        """
        Return glyphs number in this font.
        """
    def HasSymbol(self,theUChar : str) -> bool: 
        """
        Return TRUE if font contains specified symbol (excluding fallback list).
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def Init(self,theFontPath : OCP.TCollection.TCollection_AsciiString,theParams : Font_FTFontParams,theFaceId : int=0) -> bool: 
        """
        Initialize the font from the given file path.

        Initialize the font from the given file path or memory buffer.

        Initialize the font.

        Initialize the font.
        """
    @overload
    def Init(self,theData : OCP.NCollection.NCollection_Buffer,theFileName : OCP.TCollection.TCollection_AsciiString,theParams : Font_FTFontParams,theFaceId : int=0) -> bool: ...
    @overload
    def Init(self,theFontPath : OCP.NCollection.NCollection_Utf8String,thePointSize : int,theResolution : int) -> bool: ...
    @overload
    def Init(self,theFontName : OCP.NCollection.NCollection_Utf8String,theFontAspect : Font_FontAspect,thePointSize : int,theResolution : int) -> bool: ...
    @staticmethod
    def IsCharFromArabic_s(theUChar : str) -> bool: 
        """
        Return TRUE if specified character is within subset of Arabic characters.
        """
    @staticmethod
    def IsCharFromCJK_s(theUChar : str) -> bool: 
        """
        Return TRUE if specified character is within subset of modern CJK characters.
        """
    @staticmethod
    def IsCharFromHiragana_s(theUChar : str) -> bool: 
        """
        Return TRUE if specified character is within subset of Hiragana (Japanese).
        """
    @staticmethod
    def IsCharFromKatakana_s(theUChar : str) -> bool: 
        """
        Return TRUE if specified character is within subset of Katakana (Japanese).
        """
    @staticmethod
    def IsCharFromKorean_s(theUChar : str) -> bool: 
        """
        Return TRUE if specified character is within subset of modern Korean characters (Hangul).
        """
    @staticmethod
    def IsCharRightToLeft_s(theUChar : str) -> bool: 
        """
        Return TRUE if specified character should be displayed in Right-to-Left order.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsSingleStrokeFont(self) -> bool: 
        """
        Return TRUE if this is single-stroke (one-line) font, FALSE by default. Such fonts define single-line glyphs instead of closed contours, so that they are rendered incorrectly by normal software.
        """
    def IsValid(self) -> bool: 
        """
        Returns true if font is loaded
        """
    def LineSpacing(self) -> float: 
        """
        Returns default line spacing (the baseline-to-baseline distance).
        """
    def PointSize(self) -> int: 
        """
        Configured point size
        """
    def Release(self) -> None: 
        """
        Release currently loaded font.
        """
    def RenderGlyph(self,theChar : str) -> bool: 
        """
        Render specified glyph into internal buffer (bitmap).
        """
    def SetSingleStrokeFont(self,theIsSingleLine : bool) -> None: 
        """
        Set if this font should be rendered as single-stroke (one-line).
        """
    def SetUseUnicodeSubsetFallback(self,theToFallback : bool) -> None: 
        """
        Set if fallback fonts should be used in case if used font does not include symbols from specific Unicode subset.
        """
    def SetWidthScaling(self,theScaleFactor : float) -> None: 
        """
        Setup glyph scaling along X-axis. By default glyphs are not scaled (scaling factor = 1.0)
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToSynthesizeItalic(self) -> bool: 
        """
        Return TRUE if italic style should be synthesized; FALSE by default.
        """
    def ToUseUnicodeSubsetFallback(self) -> bool: 
        """
        Return flag to use fallback fonts in case if used font does not include symbols from specific Unicode subset; TRUE by default.
        """
    def WidthScaling(self) -> float: 
        """
        Return glyph scaling along X-axis.
        """
    def __init__(self,theFTLib : Font_FTLibrary=None) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Font_FTFontParams():
    """
    Font initialization parameters.
    """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,thePointSize : int,theResolution : int) -> None: ...
    @property
    def FontHinting(self) -> Font_Hinting:
        """
        :type: Font_Hinting
        """
    @FontHinting.setter
    def FontHinting(self, arg0: Font_Hinting) -> None:
        pass
    pass
class Font_FTLibrary(OCP.Standard.Standard_Transient):
    """
    Wrapper over FT_Library. Provides access to FreeType library.Wrapper over FT_Library. Provides access to FreeType library.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Instance(self) -> FT_LibraryRec_: 
        """
        Access FT_Library instance.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsValid(self) -> bool: 
        """
        This method should always return true.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Font_FontAspect():
    """
    Specifies aspect of system font.

    Members:

      Font_FontAspect_UNDEFINED

      Font_FontAspect_Regular

      Font_FontAspect_Bold

      Font_FontAspect_Italic

      Font_FontAspect_BoldItalic

      Font_FA_Undefined

      Font_FA_Regular

      Font_FA_Bold

      Font_FA_Italic

      Font_FA_BoldItalic
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Font_FA_Bold: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Bold: 1>
    Font_FA_BoldItalic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_BoldItalic: 3>
    Font_FA_Italic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Italic: 2>
    Font_FA_Regular: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Regular: 0>
    Font_FA_Undefined: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_UNDEFINED: -1>
    Font_FontAspect_Bold: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Bold: 1>
    Font_FontAspect_BoldItalic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_BoldItalic: 3>
    Font_FontAspect_Italic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Italic: 2>
    Font_FontAspect_Regular: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Regular: 0>
    Font_FontAspect_UNDEFINED: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_UNDEFINED: -1>
    __entries: dict # value = {'Font_FontAspect_UNDEFINED': (<Font_FontAspect.Font_FontAspect_UNDEFINED: -1>, None), 'Font_FontAspect_Regular': (<Font_FontAspect.Font_FontAspect_Regular: 0>, None), 'Font_FontAspect_Bold': (<Font_FontAspect.Font_FontAspect_Bold: 1>, None), 'Font_FontAspect_Italic': (<Font_FontAspect.Font_FontAspect_Italic: 2>, None), 'Font_FontAspect_BoldItalic': (<Font_FontAspect.Font_FontAspect_BoldItalic: 3>, None), 'Font_FA_Undefined': (<Font_FontAspect.Font_FontAspect_UNDEFINED: -1>, None), 'Font_FA_Regular': (<Font_FontAspect.Font_FontAspect_Regular: 0>, None), 'Font_FA_Bold': (<Font_FontAspect.Font_FontAspect_Bold: 1>, None), 'Font_FA_Italic': (<Font_FontAspect.Font_FontAspect_Italic: 2>, None), 'Font_FA_BoldItalic': (<Font_FontAspect.Font_FontAspect_BoldItalic: 3>, None)}
    __members__: dict # value = {'Font_FontAspect_UNDEFINED': <Font_FontAspect.Font_FontAspect_UNDEFINED: -1>, 'Font_FontAspect_Regular': <Font_FontAspect.Font_FontAspect_Regular: 0>, 'Font_FontAspect_Bold': <Font_FontAspect.Font_FontAspect_Bold: 1>, 'Font_FontAspect_Italic': <Font_FontAspect.Font_FontAspect_Italic: 2>, 'Font_FontAspect_BoldItalic': <Font_FontAspect.Font_FontAspect_BoldItalic: 3>, 'Font_FA_Undefined': <Font_FontAspect.Font_FontAspect_UNDEFINED: -1>, 'Font_FA_Regular': <Font_FontAspect.Font_FontAspect_Regular: 0>, 'Font_FA_Bold': <Font_FontAspect.Font_FontAspect_Bold: 1>, 'Font_FA_Italic': <Font_FontAspect.Font_FontAspect_Italic: 2>, 'Font_FA_BoldItalic': <Font_FontAspect.Font_FontAspect_BoldItalic: 3>}
    pass
class Font_FontMgr(OCP.Standard.Standard_Transient):
    """
    Collects and provides information about available fonts in system.Collects and provides information about available fonts in system.
    """
    def AddFontAlias(self,theAliasName : OCP.TCollection.TCollection_AsciiString,theFontName : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        Register font alias.
        """
    def AvailableFonts(self,theList : Font_NListOfSystemFont) -> None: 
        """
        Return the list of available fonts.
        """
    @overload
    def CheckFont(self,theFonts : Any,theFontPath : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        Read font file and retrieve information from it (the list of font faces).

        Read font file and retrieve information from it.
        """
    @overload
    def CheckFont(self,theFontPath : str) -> Font_SystemFont: ...
    def ClearFontDataBase(self) -> None: 
        """
        Clear registry. Can be used for testing purposes.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def EmbedFallbackFont_s() -> OCP.NCollection.NCollection_Buffer: 
        """
        Return DejaVu font as embed a single fallback font. It can be used in cases when there is no own font file. Note: result buffer is readonly and should not be changed, any data modification can lead to unpredictable consequences.
        """
    def FindFallbackFont(self,theSubset : Font_UnicodeSubset,theFontAspect : Font_FontAspect) -> Font_SystemFont: 
        """
        Tries to find fallback font for specified Unicode subset. Returns NULL in case when fallback font is not found in the system.
        """
    @overload
    def FindFont(self,theFontName : OCP.TCollection.TCollection_AsciiString,theStrictLevel : Font_StrictLevel,theFontAspect : Font_FontAspect,theDoFailMsg : bool=True) -> Font_SystemFont: 
        """
        Tries to find font by given parameters. If the specified font is not found tries to use font names mapping. If the requested family name not found -> search for any font family with given aspect and height. If the font is still not found, returns any font available in the system. Returns NULL in case when the fonts are not found in the system.

        Tries to find font by given parameters.
        """
    @overload
    def FindFont(self,theFontName : OCP.TCollection.TCollection_AsciiString,theFontAspect : Font_FontAspect) -> Font_SystemFont: ...
    @staticmethod
    def FontAspectToString_s(theAspect : Font_FontAspect) -> str: 
        """
        Return font aspect as string.
        """
    def GetAllAliases(self,theAliases : OCP.TColStd.TColStd_SequenceOfHAsciiString) -> None: 
        """
        Return font names with defined aliases.
        """
    def GetAvailableFonts(self) -> Font_NListOfSystemFont: 
        """
        Return the list of available fonts.
        """
    def GetAvailableFontsNames(self,theFontsNames : OCP.TColStd.TColStd_SequenceOfHAsciiString) -> None: 
        """
        Returns sequence of available fonts names
        """
    @overload
    def GetFont(self,theFontName : OCP.TCollection.TCollection_HAsciiString,theFontAspect : Font_FontAspect,theFontSize : int) -> Font_SystemFont: 
        """
        Returns font that match given parameters. If theFontName is empty string returned font can have any FontName. If theFontAspect is Font_FA_Undefined returned font can have any FontAspect. If theFontSize is "-1" returned font can have any FontSize.

        Returns font that match given name or NULL if such font family is NOT registered. Note that unlike FindFont(), this method ignores font aliases and does not look for fall-back.
        """
    @overload
    def GetFont(self,theFontName : OCP.TCollection.TCollection_AsciiString) -> Font_SystemFont: ...
    def GetFontAliases(self,theFontNames : OCP.TColStd.TColStd_SequenceOfHAsciiString,theAliasName : OCP.TCollection.TCollection_AsciiString) -> None: 
        """
        Return aliases to specified font name.
        """
    @staticmethod
    def GetInstance_s() -> Font_FontMgr: 
        """
        Return global instance of font manager.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def InitFontDataBase(self) -> None: 
        """
        Collects available fonts paths.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def RegisterFont(self,theFont : Font_SystemFont,theToOverride : bool) -> bool: 
        """
        Register new font. If there is existing entity with the same name and properties but different path then font will be overridden or ignored depending on theToOverride flag.
        """
    def RegisterFonts(self,theFonts : Any,theToOverride : bool) -> bool: 
        """
        Register new fonts.
        """
    def RemoveFontAlias(self,theAliasName : OCP.TCollection.TCollection_AsciiString,theFontName : OCP.TCollection.TCollection_AsciiString) -> bool: 
        """
        Unregister font alias.
        """
    def SetTraceAliases(self,theToTrace : bool) -> None: 
        """
        Set flag for tracing font alias usage; useful to trace which fonts are actually used. Can be disabled to avoid redundant messages with Message_Trace level.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToTraceAliases(self) -> bool: 
        """
        Return flag for tracing font aliases usage via Message_Trace messages; TRUE by default.
        """
    @staticmethod
    def ToUseUnicodeSubsetFallback_s() -> bool: 
        """
        Return flag to use fallback fonts in case if used font does not include symbols from specific Unicode subset; TRUE by default.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Font_Hinting():
    """
    Enumeration defining font hinting options.

    Members:

      Font_Hinting_Off

      Font_Hinting_Normal

      Font_Hinting_Light

      Font_Hinting_ForceAutohint

      Font_Hinting_NoAutohint
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Font_Hinting_ForceAutohint: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_ForceAutohint: 16>
    Font_Hinting_Light: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_Light: 2>
    Font_Hinting_NoAutohint: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_NoAutohint: 32>
    Font_Hinting_Normal: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_Normal: 1>
    Font_Hinting_Off: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_Off: 0>
    __entries: dict # value = {'Font_Hinting_Off': (<Font_Hinting.Font_Hinting_Off: 0>, None), 'Font_Hinting_Normal': (<Font_Hinting.Font_Hinting_Normal: 1>, None), 'Font_Hinting_Light': (<Font_Hinting.Font_Hinting_Light: 2>, None), 'Font_Hinting_ForceAutohint': (<Font_Hinting.Font_Hinting_ForceAutohint: 16>, None), 'Font_Hinting_NoAutohint': (<Font_Hinting.Font_Hinting_NoAutohint: 32>, None)}
    __members__: dict # value = {'Font_Hinting_Off': <Font_Hinting.Font_Hinting_Off: 0>, 'Font_Hinting_Normal': <Font_Hinting.Font_Hinting_Normal: 1>, 'Font_Hinting_Light': <Font_Hinting.Font_Hinting_Light: 2>, 'Font_Hinting_ForceAutohint': <Font_Hinting.Font_Hinting_ForceAutohint: 16>, 'Font_Hinting_NoAutohint': <Font_Hinting.Font_Hinting_NoAutohint: 32>}
    pass
class Font_NListOfSystemFont(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : Font_SystemFont) -> Font_SystemFont: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : Font_SystemFont,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : Font_NListOfSystemFont) -> None: ...
    def Assign(self,theOther : Font_NListOfSystemFont) -> Font_NListOfSystemFont: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> Font_SystemFont: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : Font_SystemFont,theIter : Any) -> Font_SystemFont: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : Font_NListOfSystemFont,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : Font_SystemFont,theIter : Any) -> Font_SystemFont: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : Font_NListOfSystemFont,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> Font_SystemFont: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : Font_SystemFont) -> Font_SystemFont: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : Font_NListOfSystemFont) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : Font_NListOfSystemFont) -> None: ...
    def __iter__(self) -> Iterator[Font_SystemFont]: ...
    def __len__(self) -> int: ...
    pass
class Font_Rect():
    """
    Auxiliary POD structure - 2D rectangle definition.
    """
    def BottomLeft(self,theVec : OCP.gp.gp_Vec2f) -> OCP.gp.gp_Vec2f: 
        """
        Bottom-left corner as vec2.
        """
    def BottomRight(self,theVec : OCP.gp.gp_Vec2f) -> OCP.gp.gp_Vec2f: 
        """
        Bottom-right corner as vec2.
        """
    def DumpJson(self,theOStream : io.BytesIO,arg1 : int) -> None: 
        """
        Dumps the content of me into the stream
        """
    def Height(self) -> float: 
        """
        Rectangle height.
        """
    @overload
    def TopLeft(self) -> OCP.gp.gp_Vec2f: 
        """
        Top-left corner as vec2.

        Top-left corner as vec2.
        """
    @overload
    def TopLeft(self,theVec : OCP.gp.gp_Vec2f) -> OCP.gp.gp_Vec2f: ...
    def TopRight(self,theVec : OCP.gp.gp_Vec2f) -> OCP.gp.gp_Vec2f: 
        """
        Top-right corner as vec2.
        """
    def Width(self) -> float: 
        """
        Rectangle width.
        """
    def __init__(self) -> None: ...
    pass
class Font_StrictLevel():
    """
    Enumeration defining font search restrictions.

    Members:

      Font_StrictLevel_Strict

      Font_StrictLevel_Aliases

      Font_StrictLevel_Any
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Font_StrictLevel_Aliases: OCP.Font.Font_StrictLevel # value = <Font_StrictLevel.Font_StrictLevel_Aliases: 1>
    Font_StrictLevel_Any: OCP.Font.Font_StrictLevel # value = <Font_StrictLevel.Font_StrictLevel_Any: 2>
    Font_StrictLevel_Strict: OCP.Font.Font_StrictLevel # value = <Font_StrictLevel.Font_StrictLevel_Strict: 0>
    __entries: dict # value = {'Font_StrictLevel_Strict': (<Font_StrictLevel.Font_StrictLevel_Strict: 0>, None), 'Font_StrictLevel_Aliases': (<Font_StrictLevel.Font_StrictLevel_Aliases: 1>, None), 'Font_StrictLevel_Any': (<Font_StrictLevel.Font_StrictLevel_Any: 2>, None)}
    __members__: dict # value = {'Font_StrictLevel_Strict': <Font_StrictLevel.Font_StrictLevel_Strict: 0>, 'Font_StrictLevel_Aliases': <Font_StrictLevel.Font_StrictLevel_Aliases: 1>, 'Font_StrictLevel_Any': <Font_StrictLevel.Font_StrictLevel_Any: 2>}
    pass
class Font_SystemFont(OCP.Standard.Standard_Transient):
    """
    This class stores information about the font, which is merely a file path and cached metadata about the font.This class stores information about the font, which is merely a file path and cached metadata about the font.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def FontFaceId(self,theAspect : Font_FontAspect) -> int: 
        """
        Returns font file path.
        """
    def FontKey(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns font family name (lower-cased).
        """
    def FontName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns font family name.
        """
    def FontPath(self,theAspect : Font_FontAspect) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns font file path.
        """
    def FontPathAny(self,theAspect : Font_FontAspect,theToSynthesizeItalic : bool,theFaceId : int) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns any defined font file path.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasFontAspect(self,theAspect : Font_FontAspect) -> bool: 
        """
        Returns TRUE if dedicated file for specified font aspect has been defined.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEqual(self,theOtherFont : Font_SystemFont) -> bool: 
        """
        Return true if the FontName, FontAspect and FontSize are the same.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsSingleStrokeFont(self) -> bool: 
        """
        Return TRUE if this is single-stroke (one-line) font, FALSE by default. Such fonts define single-line glyphs instead of closed contours, so that they are rendered incorrectly by normal software.
        """
    def SetFontPath(self,theAspect : Font_FontAspect,thePath : OCP.TCollection.TCollection_AsciiString,theFaceId : int=0) -> None: 
        """
        Sets font file path for specific aspect.
        """
    def SetSingleStrokeFont(self,theIsSingleLine : bool) -> None: 
        """
        Set if this font should be rendered as single-stroke (one-line).
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToString(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Format font description.
        """
    def __init__(self,theFontName : OCP.TCollection.TCollection_AsciiString) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class Font_TextFormatter(OCP.Standard.Standard_Transient):
    """
    This class is intended to prepare formatted text by using: - font to string combination, - alignment, - wrapping.This class is intended to prepare formatted text by using: - font to string combination, - alignment, - wrapping.
    """
    class IterationFilter_e():
        """
        Iteration filter flags. Command symbols are skipped with any filter.

        Members:

          IterationFilter_None

          IterationFilter_ExcludeInvisible
        """
        def __eq__(self,other : object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __init__(self,value : int) -> None: ...
        def __int__(self) -> int: ...
        def __ne__(self,other : object) -> bool: ...
        def __repr__(self) -> str: ...
        def __setstate__(self,state : int) -> None: ...
        def __str__(self) -> str: ...
        @property
        def name(self) -> None:
            """
            :type: None
            """
        @property
        def value(self) -> int:
            """
            :type: int
            """
        IterationFilter_ExcludeInvisible: OCP.Font.IterationFilter_e # value = <IterationFilter_e.IterationFilter_ExcludeInvisible: 2>
        IterationFilter_None: OCP.Font.IterationFilter_e # value = <IterationFilter_e.IterationFilter_None: 0>
        __entries: dict # value = {'IterationFilter_None': (<IterationFilter_e.IterationFilter_None: 0>, None), 'IterationFilter_ExcludeInvisible': (<IterationFilter_e.IterationFilter_ExcludeInvisible: 2>, None)}
        __members__: dict # value = {'IterationFilter_None': <IterationFilter_e.IterationFilter_None: 0>, 'IterationFilter_ExcludeInvisible': <IterationFilter_e.IterationFilter_ExcludeInvisible: 2>}
        pass
    def Append(self,theString : OCP.NCollection.NCollection_Utf8String,theFont : Font_FTFont) -> None: 
        """
        Render specified text to inner buffer.
        """
    def BndBox(self,theBndBox : Font_Rect) -> None: ...
    def BottomLeft(self,theIndex : int) -> OCP.gp.gp_Vec2f: 
        """
        Returns specific glyph rectangle.
        """
    def Corners(self) -> Any: 
        """
        Returns internal container of the top left corners of a formatted rectangles.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def FirstPosition(self) -> float: 
        """
        Returns position of the first symbol in a line using alignment
        """
    def Format(self) -> None: 
        """
        Perform formatting on the buffered text. Should not be called more than once after initialization!
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GlyphBoundingBox(self,theIndex : int,theBndBox : Font_Rect) -> bool: 
        """
        Returns symbol bounding box
        """
    def HasWrapping(self) -> bool: 
        """
        Returns text maximum width, zero means that the text is not bounded by width
        """
    def HorizontalTextAlignment(self) -> OCP.Graphic3d.Graphic3d_HorizontalTextAlignment: 
        """
        Returns horizontal alignment style
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @staticmethod
    def IsCommandSymbol_s(theSymbol : str) -> bool: 
        """
        Returns true if the symbol is CR, BEL, FF, NP, BS or VT
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsLFSymbol(self,theIndex : int) -> bool: 
        """
        Returns true if the symbol by the index is ''. The width of the symbol is zero.
        """
    @staticmethod
    def IsSeparatorSymbol_s(theSymbol : str) -> bool: 
        """
        Returns true if the symbol separates words when wrapping is enabled
        """
    def LineHeight(self,theIndex : int) -> float: 
        """
        Returns the line height
        """
    def LineIndex(self,theIndex : int) -> int: 
        """
        Returns row index of the corner index among text lines
        """
    def LinePositionIndex(self,theIndex : int) -> int: 
        """
        Returns column index of the corner index in the current line
        """
    def LineWidth(self,theIndex : int) -> float: 
        """
        Returns width of a line
        """
    def MaximumSymbolWidth(self) -> float: 
        """
        Returns maximum width of the text symbol
        """
    def NewLines(self) -> Any: 
        """
        Returns container of each line position at LF in formatted text
        """
    def Reset(self) -> None: 
        """
        Reset current progress.
        """
    def ResultHeight(self) -> float: 
        """
        Returns height of formatted text.
        """
    def ResultWidth(self) -> float: 
        """
        Returns width of formatted text.
        """
    def SetWordWrapping(self,theIsWordWrapping : bool) -> None: 
        """
        returns TRUE when trying not to break words when wrapping text
        """
    def SetWrapping(self,theWidth : float) -> None: 
        """
        Sets text wrapping width, zero means that the text is not bounded by width
        """
    def SetupAlignment(self,theAlignX : OCP.Graphic3d.Graphic3d_HorizontalTextAlignment,theAlignY : OCP.Graphic3d.Graphic3d_VerticalTextAlignment) -> None: 
        """
        Setup alignment style.
        """
    def String(self) -> OCP.NCollection.NCollection_Utf8String: 
        """
        Returns current rendering string.
        """
    def TabSize(self) -> int: 
        """
        Returns tab size.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TopLeft(self,theIndex : int) -> OCP.gp.gp_Vec2f: ...
    def VerticalTextAlignment(self) -> OCP.Graphic3d.Graphic3d_VerticalTextAlignment: 
        """
        Returns vertical alignment style
        """
    def WordWrapping(self) -> bool: 
        """
        returns TRUE when trying not to break words when wrapping text
        """
    def Wrapping(self) -> float: 
        """
        Returns text maximum width, zero means that the text is not bounded by width
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    IterationFilter_ExcludeInvisible: OCP.Font.IterationFilter_e # value = <IterationFilter_e.IterationFilter_ExcludeInvisible: 2>
    IterationFilter_None: OCP.Font.IterationFilter_e # value = <IterationFilter_e.IterationFilter_None: 0>
    pass
class Font_UnicodeSubset():
    """
    Enumeration defining Unicode subsets.

    Members:

      Font_UnicodeSubset_Western

      Font_UnicodeSubset_Korean

      Font_UnicodeSubset_CJK

      Font_UnicodeSubset_Arabic
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    Font_UnicodeSubset_Arabic: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_Arabic: 3>
    Font_UnicodeSubset_CJK: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_CJK: 2>
    Font_UnicodeSubset_Korean: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_Korean: 1>
    Font_UnicodeSubset_Western: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_Western: 0>
    __entries: dict # value = {'Font_UnicodeSubset_Western': (<Font_UnicodeSubset.Font_UnicodeSubset_Western: 0>, None), 'Font_UnicodeSubset_Korean': (<Font_UnicodeSubset.Font_UnicodeSubset_Korean: 1>, None), 'Font_UnicodeSubset_CJK': (<Font_UnicodeSubset.Font_UnicodeSubset_CJK: 2>, None), 'Font_UnicodeSubset_Arabic': (<Font_UnicodeSubset.Font_UnicodeSubset_Arabic: 3>, None)}
    __members__: dict # value = {'Font_UnicodeSubset_Western': <Font_UnicodeSubset.Font_UnicodeSubset_Western: 0>, 'Font_UnicodeSubset_Korean': <Font_UnicodeSubset.Font_UnicodeSubset_Korean: 1>, 'Font_UnicodeSubset_CJK': <Font_UnicodeSubset.Font_UnicodeSubset_CJK: 2>, 'Font_UnicodeSubset_Arabic': <Font_UnicodeSubset.Font_UnicodeSubset_Arabic: 3>}
    pass
def IsEqual(theFirstFont : Font_SystemFont,theSecondFont : Font_SystemFont) -> bool:
    pass
Font_FA_Bold: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Bold: 1>
Font_FA_BoldItalic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_BoldItalic: 3>
Font_FA_Italic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Italic: 2>
Font_FA_Regular: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Regular: 0>
Font_FA_Undefined: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_UNDEFINED: -1>
Font_FontAspect_Bold: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Bold: 1>
Font_FontAspect_BoldItalic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_BoldItalic: 3>
Font_FontAspect_Italic: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Italic: 2>
Font_FontAspect_NB = 4
Font_FontAspect_Regular: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_Regular: 0>
Font_FontAspect_UNDEFINED: OCP.Font.Font_FontAspect # value = <Font_FontAspect.Font_FontAspect_UNDEFINED: -1>
Font_Hinting_ForceAutohint: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_ForceAutohint: 16>
Font_Hinting_Light: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_Light: 2>
Font_Hinting_NoAutohint: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_NoAutohint: 32>
Font_Hinting_Normal: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_Normal: 1>
Font_Hinting_Off: OCP.Font.Font_Hinting # value = <Font_Hinting.Font_Hinting_Off: 0>
Font_StrictLevel_Aliases: OCP.Font.Font_StrictLevel # value = <Font_StrictLevel.Font_StrictLevel_Aliases: 1>
Font_StrictLevel_Any: OCP.Font.Font_StrictLevel # value = <Font_StrictLevel.Font_StrictLevel_Any: 2>
Font_StrictLevel_Strict: OCP.Font.Font_StrictLevel # value = <Font_StrictLevel.Font_StrictLevel_Strict: 0>
Font_UnicodeSubset_Arabic: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_Arabic: 3>
Font_UnicodeSubset_CJK: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_CJK: 2>
Font_UnicodeSubset_Korean: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_Korean: 1>
Font_UnicodeSubset_NB = 3
Font_UnicodeSubset_Western: OCP.Font.Font_UnicodeSubset # value = <Font_UnicodeSubset.Font_UnicodeSubset_Western: 0>
